package App::Cinema::Model::MD;
use Moose;
BEGIN {
	extends 'Catalyst::Model::DBIC::Schema';
	our $VERSION = $App::Cinema::VERSION;
}

=head1 NAME

App::Cinema::Model::MD - Catalyst DBIC Schema Model

=head1 SYNOPSIS

See L<App::Cinema>

=head1 DESCRIPTION

L<Catalyst::Model::DBIC::Schema> Model using schema L<App::Cinema::Schema>

=head1 GENERATED BY

Catalyst::Helper::Model::DBIC::Schema - 0.33

=head1 AUTHOR

Jeff Mo

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
